@@ -1,11 +1,11 @@
 package WebService::Braintree::CreditCardVerificationSearch;
-$WebService::Braintree::CreditCardVerificationSearch::VERSION = '0.31';
+$WebService::Braintree::CreditCardVerificationSearch::VERSION = '0.4';
 use Moose;
 use WebService::Braintree::CreditCard::CardType;
-use WebService::Braintree::AdvancedSearch;
+use WebService::Braintree::AdvancedSearch qw(search_to_hash);
+my $meta = __PACKAGE__->meta();
 
-
-my $field = WebService::Braintree::AdvancedSearchFields->new(metaclass => __PACKAGE__->meta);
+my $field = WebService::Braintree::AdvancedSearchFields->new(metaclass => $meta);
 $field->text("id");
 $field->text("credit_card_cardholder_name");
 $field->equality("credit_card_expiration_date");
