@@ -1,14 +1,13 @@
 package WebService::Braintree::Disbursement;
-$WebService::Braintree::Disbursement::VERSION = '0.31';
+$WebService::Braintree::Disbursement::VERSION = '0.4';
 
 use Moose;
 extends "WebService::Braintree::ResultObject";
-
-has  merchant_account => (is => 'rw');
+my $meta = __PACKAGE__->meta;
 
 sub BUILD {
     my ($self, $attributes) = @_;
-
+    $meta->add_attribute('merchant_account', is => 'rw');
     $self->merchant_account(WebService::Braintree::MerchantAccount->new($attributes->{merchant_account}));
     delete($attributes->{merchant_account});
     $self->set_attributes_from_hash($self, $attributes);
@@ -22,6 +21,4 @@ sub transactions {
                                                });
 }
 
-
-__PACKAGE__->meta->make_immutable;
 1;
