@@ -1,5 +1,5 @@
 package WebService::Braintree::Dispute;
-$WebService::Braintree::Dispute::VERSION = '0.31';
+$WebService::Braintree::Dispute::VERSION = '0.4';
 use WebService::Braintree::Dispute::TransactionDetails;
 use WebService::Braintree::Dispute::Status;
 use WebService::Braintree::Dispute::Reason;
@@ -7,15 +7,13 @@ use WebService::Braintree::Dispute::Reason;
 use Moose;
 extends 'WebService::Braintree::ResultObject';
 
-has  transaction_details => (is => 'rw');
-
 sub BUILD {
     my ($self, $attributes) = @_;
-
+    my $meta = __PACKAGE__->meta;
+    $meta->add_attribute('transaction_details', is => 'rw');
     $self->transaction_details(WebService::Braintree::Dispute::TransactionDetails->new($attributes->{transaction})) if ref($attributes->{transaction}) eq 'HASH';
     delete($attributes->{transaction});
     $self->set_attributes_from_hash($self, $attributes);
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
