@@ -1,5 +1,5 @@
 package WebService::Braintree::MerchantAccount;
-$WebService::Braintree::MerchantAccount::VERSION = '0.31';
+$WebService::Braintree::MerchantAccount::VERSION = '0.4';
 use WebService::Braintree::MerchantAccount::IndividualDetails;
 use WebService::Braintree::MerchantAccount::AddressDetails;
 use WebService::Braintree::MerchantAccount::BusinessDetails;
@@ -10,7 +10,7 @@ extends "WebService::Braintree::ResultObject";
 
 {
     package WebService::Braintree::MerchantAccount::Status;
-$WebService::Braintree::MerchantAccount::Status::VERSION = '0.31';
+$WebService::Braintree::MerchantAccount::Status::VERSION = '0.4';
 use constant Active => "active";
     use constant Pending => "pending";
     use constant Suspended => "suspended";
@@ -18,32 +18,28 @@ use constant Active => "active";
 
 {
     package WebService::Braintree::MerchantAccount::FundingDestination;
-$WebService::Braintree::MerchantAccount::FundingDestination::VERSION = '0.31';
+$WebService::Braintree::MerchantAccount::FundingDestination::VERSION = '0.4';
 use constant Bank => "bank";
     use constant Email => "email";
     use constant MobilePhone => "mobile_phone";
 }
 
-has  master_merchant_account => (is => 'rw');
-has  individual_details => (is => 'rw');
-has  business_details => (is => 'rw');
-has  funding_details => (is => 'rw');
-
 sub BUILD {
     my ($self, $attributes) = @_;
-
+    my $meta = __PACKAGE__->meta;
+    $meta->add_attribute('master_merchant_account', is => 'rw');
     $self->master_merchant_account(WebService::Braintree::MerchantAccount->new($attributes->{master_merchant_account})) if ref($attributes->{master_merchant_account}) eq 'HASH';
     delete($attributes->{master_merchant_account});
 
-
+    $meta->add_attribute('individual_details', is => 'rw');
     $self->individual_details(WebService::Braintree::MerchantAccount::IndividualDetails->new($attributes->{individual})) if ref($attributes->{individual}) eq 'HASH';
     delete($attributes->{individual});
 
-
+    $meta->add_attribute('business_details', is => 'rw');
     $self->business_details(WebService::Braintree::MerchantAccount::BusinessDetails->new($attributes->{business})) if ref($attributes->{business}) eq 'HASH';
     delete($attributes->{business});
 
-
+    $meta->add_attribute('funding_details', is => 'rw');
     $self->funding_details(WebService::Braintree::MerchantAccount::FundingDetails->new($attributes->{funding})) if ref($attributes->{funding}) eq 'HASH';
     delete($attributes->{funding});
 
@@ -69,5 +65,4 @@ sub gateway {
     return WebService::Braintree->configuration->gateway;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
