@@ -1,7 +1,7 @@
 package WebService::Braintree::SubscriptionSearch;
-$WebService::Braintree::SubscriptionSearch::VERSION = '0.31';
+$WebService::Braintree::SubscriptionSearch::VERSION = '0.4';
 use Moose;
-use WebService::Braintree::AdvancedSearch;
+use WebService::Braintree::AdvancedSearch qw(search_to_hash);
 
 my $field = WebService::Braintree::AdvancedSearchFields->new(metaclass => __PACKAGE__->meta);
 
